@@ -17,7 +17,7 @@ from typing import Any, Dict, Mapping, Type
 
 from botocore.client import BaseClient, ClientMeta
 
-from .type_defs import QueryForecastResponseTypeDef
+from .type_defs import QueryForecastResponseTypeDef, QueryWhatIfForecastResponseTypeDef
 
 __all__ = ("ForecastQueryServiceClient",)
 
@@ -101,3 +101,19 @@ class ForecastQueryServiceClient(BaseClient):
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.query_forecast)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#query_forecast)
         """
+
+    def query_what_if_forecast(
+        self,
+        *,
+        WhatIfForecastArn: str,
+        Filters: Mapping[str, str],
+        StartDate: str = ...,
+        EndDate: str = ...,
+        NextToken: str = ...
+    ) -> QueryWhatIfForecastResponseTypeDef:
+        """
+        Retrieves a what-if forecast.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/forecastquery.html#ForecastQueryService.Client.query_what_if_forecast)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_forecastquery/client/#query_what_if_forecast)
+        """
